Below is the list of changes that have just been commited into a local
3.23. repository of sasha. When sasha does a push, they will be
propogaged to the main repository and within 24 hours after the push into
the public repository. For information on how to access
the public repository see
http://www.mysql.com/doc/I/n/Installing_source_tree.html
ChangeSet@stripped, 2002-02-16 11:32:06-07:00, sasha@stripped
updated build scripts for new Linux build
Build-tools/Do-linux-build
1.1 02/02/16 11:32:06 sasha@stripped +18 -0
Build-tools/Do-all-build-steps
1.32 02/02/16 11:32:06 sasha@stripped +1 -1
pass parameters to Do-rpm
Build-tools/Do-compile
1.40 02/02/16 11:32:06 sasha@stripped +5 -1
with-other-libc option
Build-tools/Do-linux-build
1.0 02/02/16 11:32:06 sasha@stripped +0 -0
BitKeeper file /reiser-data/mysql/Build-tools/Do-linux-build
Build-tools/Do-rpm
1.16 02/02/16 11:32:06 sasha@stripped +15 -1
make it "automagically" work on SuSE as well as RedHat
strings/Makefile.am
1.16 02/02/16 11:32:06 sasha@stripped +2 -1
added t_ctype.h to the distribution for now - permanent fix to come later
support-files/mysql.spec.sh
1.37 02/02/16 11:32:06 sasha@stripped +19 -4
changed build to use --with-other-libc
# This is a BitKeeper patch. What follows are the unified diffs for the
# set of deltas contained in the patch. The rest of the patch, the part
# that BitKeeper cares about, is below these diffs.
# User: sasha
# Host: mysql.sashanet.com
# Root: /reiser-data/mysql
--- 1.31/Build-tools/Do-all-build-steps Thu Feb 14 10:24:48 2002
+++ 1.32/Build-tools/Do-all-build-steps Sat Feb 16 11:32:06 2002
@@ -72,7 +72,7 @@
time gmake -j 2 distcheck \
EXTRA_CONF_ARGS="--with-unix-socket-path=/var/tmp/mysql.sock --with-low-memory $EXTRA_CONFIG"
-sh $BD/Build-tools/Do-rpm
+sh $BD/Build-tools/Do-rpm $*
rm -f $TMP_SCRIPT
END
--- 1.39/Build-tools/Do-compile Thu Feb 14 10:24:48 2002
+++ 1.40/Build-tools/Do-compile Sat Feb 16 11:32:06 2002
@@ -7,7 +7,7 @@
$opt_help=$opt_Information=$opt_delete=$opt_debug=$opt_stage=$opt_rsh_mail=$opt_no_test=$opt_no_perl=$opt_with_low_memory=$opt_fast_benchmark=$opt_static_client=$opt_static_server=$opt_static_perl=$opt_sur=$opt_with_small_disk=$opt_local_perl=$opt_tcpip=$opt_build_thread=$opt_no_mysqltest=$opt_use_old_distribution=$opt_enable_shared=$opt_no_crash_me=$opt_no_strip=0;
$opt_innodb=$opt_bdb=0;
-GetOptions("Information","help","distribution=s","user=s","result=s","delete","no-test","no-mysqltest","perl-files=s","debug","config-options=s","config-env=s","stage=i","rsh-mail","with-low-memory","fast-benchmark","tmp=s","static-client","static-server","static-perl","no-perl","local-perl","perl-options=s","sur","with-small-disk","dbd-options=s","tcpip","suffix=s","build-thread=i","innodb","bdb","use-old-distribution","enable-shared","no-crash-me","no-strip","version-suffix=s") || usage();
+GetOptions("Information","help","distribution=s","user=s","result=s","delete","no-test","no-mysqltest","perl-files=s","debug","config-options=s","config-env=s","stage=i","rsh-mail","with-low-memory","fast-benchmark","tmp=s","static-client","static-server","static-perl","no-perl","local-perl","perl-options=s","sur","with-small-disk","dbd-options=s","tcpip","suffix=s","build-thread=i","innodb","bdb","use-old-distribution","enable-shared","no-crash-me","no-strip","version-suffix=s", "with-other-libc=s) || usage();
usage() if ($opt_help || $opt_Information);
usage() if (!$opt_distribution);
@@ -146,6 +146,10 @@
if ($opt_static_client)
{
$opt_config_options.=" --with-client-ldflags=-all-static";
+ }
+ if ($opt_with_other_libc)
+ {
+ $opt_with_other_libc = "--with-other-libc=$opt_with_other_libc";
}
if (!$opt_enable_shared)
{
--- 1.15/Build-tools/Do-rpm Tue Oct 2 14:14:48 2001
+++ 1.16/Build-tools/Do-rpm Sat Feb 16 11:32:06 2002
@@ -38,7 +38,21 @@
# Hard path!!
bpath=`/bin/pwd`
-rpmdir="/usr/src/redhat"
+
+for d in /usr/src/redhat /usr/src/packages ; do
+if test -d "$d"
+then
+ rpmdir=$d
+fi
+done
+
+if test -z "$rpmdir"
+then
+ echo "Could not find suitable rpmdir on this system"
+ exit 1
+fi
+
+
logdir="$bpath/Logs"
###### Perl STUFF #####
--- 1.15/strings/Makefile.am Mon Apr 2 19:00:53 2001
+++ 1.16/strings/Makefile.am Sat Feb 16 11:32:06 2002
@@ -51,7 +51,8 @@
strmake.c strnmov.c strmov.c strnlen.c \
bmove_upp-sparc.s strappend-sparc.s strend-sparc.s \
strinstr-sparc.s strmake-sparc.s strmov-sparc.s \
- strnmov-sparc.s strstr-sparc.s strxmov-sparc.s
+ strnmov-sparc.s strstr-sparc.s strxmov-sparc.s \
+ t_ctype.h
OMIT_DEPENDENCIES = pthread.h stdio.h __stdio.h stdlib.h __stdlib.h math.h\
__math.h time.h __time.h unistd.h __unistd.h types.h \
--- New file ---
+++ Build-tools/Do-linux-build 02/02/16 11:32:06
#! /bin/sh
set -e -x
OTHER_LIBC_DIR=/usr/local/mysql-glibc
BUILD/compile-pentium-max --with-other-libc=$OTHER_LIBC_DIR \
--with-comment="Official MySQL Binary" \
--prefix=/usr/local/mysql --with-extra-charset=complex \
--enable-thread-safe-client --enable-local-infile \
--with-server-suffix=-max
scripts/make_binary_distribution
make dist
Build-tools/Do-rpm --local
BUILD/compile-pentium --with-other-libc=$OTHER_LIBC_DIR \
--with-comment="Official MySQL Binary" \
--prefix=/usr/local/mysql --with-extra-charset=complex \
--enable-thread-safe-client --enable-local-infile
scripts/make_binary_distribution
| Thread |
|---|
| • bk commit into 3.23 tree | sasha | 16 Feb |
--- 1.36/support-files/mysql.spec.sh Thu Feb 14 10:24:48 2002
+++ 1.37/support-files/mysql.spec.sh Sat Feb 16 11:32:06 2002
@@ -186,26 +186,36 @@
# Use the build root for temporary storage of the shared libraries.
+OTHER_LIBC_DIR=/usr/local/mysql-glibc
RBR=$RPM_BUILD_ROOT
MBD=$RPM_BUILD_DIR/mysql-%{mysql_version}
if test -z "$RBR" -o "$RBR" = "/"
then
- echo "RPM_BUILD_ROOT has stupid value"
+ echo "RPM_BUILD_ROOT has insecure value"
exit 1
fi
rm -rf $RBR
mkdir -p $RBR
-# Build the shared libraries and mysqld-max
+# We need to build shared libraries separate from mysqld-max because we
+# are using --with-other-libc
-BuildMySQL "--enable-shared --enable-thread-safe-client --with-berkeley-db --with-innodb --with-mysqld-ldflags='-all-static' --with-server-suffix='-Max'"
+BuildMySQL "--disable-shared --with-other-libc=$OTHER_LIBC_DIR --with-berkeley-db --with-innodb --with-mysqld-ldflags='-all-static' --with-server-suffix='-Max'"
# Save everything for debug
# tar cf $RBR/all.tar .
-# Save shared libraries and mysqld-max
+# Save mysqld-max
mv sql/mysqld sql/mysqld-max
nm --numeric-sort sql/mysqld-max > sql/mysqld-max.sym
+
+# Save manual to avoid rebuilding
+mv Docs/manual.ps Docs/manual.ps.save
+make distclean
+mv Docs/manual.ps.save Docs/manual.ps
+
+#now build and save shared libraries
+BuildMySQL "--enable-shared --enable-thread-safe-client --without-server "
(cd libmysql/.libs; tar cf $RBR/shared-libs.tar *.so*)
(cd libmysql_r/.libs; tar rf $RBR/shared-libs.tar *.so*)
@@ -220,6 +230,7 @@
BuildMySQL "--disable-shared" \
"--with-mysqld-ldflags='-all-static'" \
"--with-client-ldflags='-all-static'" \
+ "--with-other-libc=$OTHER_LIBC_DIR" \
"--without-berkeley-db --without-innodb"
nm --numeric-sort sql/mysqld > sql/mysqld.sym
@@ -415,6 +426,10 @@
%attr(644, root, root) /usr/lib/mysql/mysqld-max.sym
%changelog
+
+* Fri Feb 15 2002 Sasha
+
+- changed build to use --with-other-libc
* Fri Apr 13 2001 Monty